##  Introduction to SAP LeanIX Architecture and Road Map Planning
While SAP LeanIX Application Portfolio Management enables you to document and build your current ('as-is') architecture, SAP LeanIX Architecture and Road Map Planning seamlessly complements this by allowing you to model future ('to-be') state architectures. With SAP LeanIX Architecture and Road Map Planning, you have the capability to model various transformations and changes in the Initiative Fact Sheet, visualize potential future states, compare various scenarios, analyze how these potential changes affect your architecture, and execute the most suitable option to arrive at your to-be state architecture.
As opposed to duplicating entire as-is architectures and creating sandbox versions of application landscapes, SAP LeanIX Architecture and Road Map Planning resourcefully only stores what is being changed to the main architecture to ensure instantaneous modeling for your organization.
![BTM: Modeling ‘To-be’ architecture](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio275721ae7a441014988dca5734eb1a82_LowRes.png)
SAP LeanIX Architecture and Road Map Planning: Modeling ‘To-be’ architecture
In SAP LeanIX Architecture and Road Map Planning, [Objective](https://help.sap.com/docs/leanix/ea/objective-modeling-guidelines?locale=en-US&state=PRODUCTION&version=CLOUD "Learn how to model objectives. This includes best practices and applicable use cases, and common antipatterns.") and [Initiative](https://help.sap.com/docs/leanix/ea/initiative-modeling-guidelines?locale=en-US&state=PRODUCTION&version=CLOUD "Learn how to model initiatives. This includes best practices and applicable use cases, and common antipatterns.") Fact Sheets have greater significance compared to their role in SAP LeanIX Application Portfolio Management product. Objective Fact Sheets allow for the high-level definition and progress tracking of transformation initiatives and can be linked to [Business Capabilities](https://help.sap.com/docs/leanix/ea/business-capability-modeling-guidelines?locale=en-US&state=PRODUCTION&version=CLOUD "This page covers modeling guidelines for business capabilities. Learn about best practices and applicable use cases, and avoid common antipatterns."). While, the Initiative Fact Sheets are used to model detailed actions for achieving an Objective. SAP LeanIX Architecture and Road Map Planning simplifies translating strategic goals into actionable IT initiatives by breaking down Objectives into Initiatives and Transformations.
Within Initiative Fact Sheets, the Transformations feature allows you to specify how a project will affect your architecture. SAP LeanIX Architecture and Road Map Planning comes with predefined Transformations, for example, Rollout Application, Upgrade Technology, Decommission Interface, etc., while you can also define custom Transformations. SAP LeanIX Architecture and Road Map Planning will automatically create relations to the Fact Sheets affected by those Transformations (e.g., from the Project to an affected Application). At the same time, it classifies and adds the type of Impact to the respective relations and fields.
The modeling of different scenarios involves the creation of new Project/Initiative Fact Sheets, each with different Transformations defined. By leveraging Reports, impacts can be compared and analyzed to choose the most effective roadmap for implementing the transformation. After buy-in from stakeholders, you can monitor the implementation with Roadmap Reports and simply execute the implemented Transformations to reflect the changes in your workspace.
![BTM Logic](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274472767a4410148a63b509066e9e67_LowRes.png)
SAP LeanIX Architecture and Road Map Planning Logic
